import typing
import collections.abc
import typing_extensions
from . import node_functions as node_functions

GenericType1 = typing.TypeVar("GenericType1")
GenericType2 = typing.TypeVar("GenericType2")
